// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import { fs } from "./rounded-rectangle-layer-fragment.js";
import { RectangleLayer } from "./rectangle-layer.js";
const uniformBlock = `\
uniform roundedRectangleUniforms {
  float cornerRadius;
} roundedRectangle;
`;
export const roundedRectangleUniforms = {
    name: 'roundedRectangle',
    vs: uniformBlock,
    fs: uniformBlock,
    uniformTypes: {
        cornerRadius: 'f32'
    }
};
export class RoundedRectangleLayer extends RectangleLayer {
    static layerName = 'RoundedRectangleLayer';
    draw(props) {
        const { cornerRadius } = this.props;
        const roundedRectangleProps = { cornerRadius };
        const model = this.state.model;
        model.shaderInputs.setProps({ roundedRectangle: roundedRectangleProps });
        super.draw(props);
    }
    getShaders() {
        // use object.assign to make sure we don't overwrite existing fields like `vs`, `modules`...
        const shaders = super.getShaders(undefined);
        return {
            ...shaders,
            fs,
            modules: [...shaders.modules, roundedRectangleUniforms]
        };
    }
}
RoundedRectangleLayer.defaultProps = {
    // cornerRadius: the amount of rounding at the rectangle corners
    // 0 - rectangle. 1 - circle.
    cornerRadius: 0.1
};
//# sourceMappingURL=rounded-rectangle-layer.js.map